@@ -20,7 +20,7 @@ if PY3:
 else:
     from StringIO import StringIO
 
-__version__ = '0.3.1'
+__version__ = '0.3.1.1'
 
 _log_name = os.getenv('USERNAME' if sys.platform == 'win32' else 'USER')
 
@@ -38,7 +38,7 @@ def _send_email(sender, receivers, subject, body, mail_server):
     """
     msg = MIMEMultipart('alternative')
     if PY3:
-        msg['subject'] = str(subject, encoding='utf-8')
+        msg['subject'] = str(subject)
     else:
         msg['subject'] = str(subject).decode('utf-8')
     msg['From'] = sender
